@@ -7,13 +7,14 @@ import (
 	"testing"
 
 	"github.com/grafana/sobek"
+	"go.k6.io/k6/internal/js/compiler"
+	"go.k6.io/k6/internal/js/eventloop"
+	"go.k6.io/k6/internal/js/modules/k6/timers"
+	"go.k6.io/k6/internal/lib/testutils"
+	"go.k6.io/k6/internal/usage"
 	"go.k6.io/k6/js/common"
-	"go.k6.io/k6/js/compiler"
-	"go.k6.io/k6/js/eventloop"
 	"go.k6.io/k6/js/modules"
-	"go.k6.io/k6/js/modules/k6/timers"
 	"go.k6.io/k6/lib"
-	"go.k6.io/k6/lib/testutils"
 	"go.k6.io/k6/metrics"
 )
 
@@ -40,6 +41,7 @@ func NewRuntime(t testing.TB) *Runtime {
 		TestPreInitState: &lib.TestPreInitState{
 			Logger:   testutils.NewLogger(t),
 			Registry: metrics.NewRegistry(),
+			Usage:    usage.New(),
 		},
 		CWD: new(url.URL),
 	}
@@ -74,7 +76,8 @@ func (r *Runtime) SetupModuleSystem(goModules map[string]any, loader modules.Fil
 		goModules["k6/timers"] = timers.New()
 	}
 
-	r.mr = modules.NewModuleResolver(goModules, loader, c, r.VU.InitEnvField.CWD)
+	r.mr = modules.NewModuleResolver(
+		goModules, loader, c, r.VU.InitEnvField.CWD, r.VU.InitEnvField.Usage, r.VU.InitEnvField.Logger)
 	return r.innerSetupModuleSystem()
 }
 
