@@ -6,10 +6,10 @@ import (
 	"sync/atomic"
 
 	"github.com/sirupsen/logrus"
-	"go.k6.io/k6/event"
-	"go.k6.io/k6/lib/trace"
+	"go.k6.io/k6/internal/event"
+	"go.k6.io/k6/internal/lib/trace"
+	"go.k6.io/k6/internal/usage"
 	"go.k6.io/k6/metrics"
-	"go.k6.io/k6/usage"
 )
 
 // TestPreInitState contains all of the state that can be gathered and built
